#
# spec file for package argus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           argus
Version:        3.0.8.3
Release:        3.3
Summary:        Network Monitoring Tool
License:        BSD-3-Clause AND GPL-2.0-only AND LGPL-2.1-only AND MIT
Group:          Productivity/Networking/Diagnostic
URL:            https://openargus.org/
Source:         https://qosient.com/argus/dev/%{name}-%{version}.tar.gz
Source3:        README.SUSE
Source4:        argus_linux.8.gz
Source5:        argus.service
Patch1:         %{name}-3.0.6.1-libpcap.patch
Patch2:         harden_argus.service.patch
Patch3:         fix-configure-libwrap-dependencies.diff
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libpcap-devel
BuildRequires:  libtirpc-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcpd-devel
BuildRequires:  tcsh

%package server
Summary:        Daemon for Network Monitoring Tool
Group:          Productivity/Networking/Diagnostic
Requires:       argus
Provides:       argus:%{_sbindir}/argus
%{?systemd_ordering}

%description
Argus is a network monitoring tool.

Documentation can be found in %{_docdir}/argus.

%description server
Daemon for Argus network monitoring tool.

%prep
%setup -q -n argus-%{version}
%patch1 -p1
cp %{SOURCE3} .
cp %{SOURCE4} man/man8/
%patch2 -p1
%patch3 -p1

%build
#autoreconf -fiv
export CFLAGS="%{optflags} -fno-strict-aliasing -fcommon"
%configure --with-pic
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/etc %{buildroot}/%{_sbindir} %{buildroot}/%{_bindir} %{buildroot}/%{_mandir} %{buildroot}/%{_docdir}
install -m 700 bin/argus %{buildroot}%{_sbindir}/argus
install -m 700 bin/arg* %{buildroot}%{_bindir}/
install -D -m 0644 %{SOURCE5} %{buildroot}/%{_unitdir}/argus.service
# alread in sbin
rm -f %{buildroot}%{_bindir}/argus
rm -f %{buildroot}%{_bindir}/argus_linux
( cd man
  cp -a man* %{buildroot}%{_mandir}
  chmod a-x %{buildroot}%{_mandir}/*/* )
rm -f %{buildroot}%{_mandir}/man1/tcpdump.1*
find -type f -name ._* -exec rm -Rf {} +
install -m 600 support/Config/argus.conf %{buildroot}%{_sysconfdir}/argus.conf
install -m 755 support/Archive/argusarchive %{buildroot}%{_bindir}/
find support -type f -exec chmod 0644 {} +
#chmod a+x support/{Archive/argusarchive,Startup/argus,System/magic}
chmod a+x support/{Archive/argusarchive,Startup/argus}

%pre server
%service_add_pre argus.service

%post server
%service_add_post argus.service

%preun server
%service_del_preun argus.service

%postun server
%service_del_postun argus.service

%files
%defattr(-,root,root)
%{_bindir}/argus*

%files server
%defattr(-,root,root)
%doc doc MANIFEST README.* support
%license COPYING
%{_mandir}/man*/*
%config %{_sysconfdir}/argus.conf
%{_unitdir}/argus.service
%{_sbindir}/*

%changelog
* Wed Jan 25 2023 Thorsten Kukuk <kukuk@suse.com>
- Replace wrong libnsl build require with correct libtirpc one
- fix-configure-libwrap-dependencies.diff: libwrap does not
  depend on libnsl
* Tue Aug 10 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_argus.service.patch
  Modified:
  * argus.service
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.0.8.3
  * Fix ekinzie-ccc-analyzer issues
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon in order to fix building with GCC10
* Thu Mar 21 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce scriptlets' hard dependency on systemd.
- Replace some UUOC by find -exec.
- Make %%install POSIX sh compatible.
* Thu Oct 26 2017 dimstar@opensuse.org
- BuildRequire libnsl-devel: since confiugure implicitly adds
  - lnsl, it is our duty to make sure deps are present.
* Wed Sep 28 2016 p.drouand@gmail.com
- Update to version 3.0.8.2
  * Upstream doesn't publish a short changelog; please read the
    ChangeLog file
* Thu Aug 27 2015 p.drouand@gmail.com
- Update to version 3.0.8.1
  * Upstream doesn't publish a short changelog; please read the
    ChangeLog file
- Use download Url as source
- Require systemd-rpm-macros instead of systemd: increase dependencies
* Thu Sep 18 2014 sfalken@opensuse.org
- Changed SuSE to SUSE in README.SUSE (sr#250033)
* Thu Sep 18 2014 sfalken@opensuse.org
- Update to 3.0.8 version:
  + Changes from 3.0.6.1:
    Update and Fixes for remote argus data filter support
    Changes for netflow packet parsing to fix netflow in clients.
    Fixes for wild metric counts in new flow data.
    Update filter logic to be consistent with client filters.
    Modifications for timeout issues when in non-select polling.
    Fix for source id type assignement from commandline
    Change for compiler timeout values
    Fixes for ARP direction processing
    Back out of duplicate packet tracking logic
    Mods for duplicate packet reporting
    Modify configure.ac for pcap_dump_flush for older libpcaps
    Modify timeouts within "nonselectable" packet processing loop.
    Use VID for the VLAN identifer for the key.
    Fix syslog while daemonized
    Remove nanosleep() to improve performance.
    Major addtions for SDN tracking.  New Flow model specifications in argus.conf.
    Fixes for solaris port, to avoid scheduling problems with record timeouts
  + Added:
    argus-3.0.8.tar.gz
    README.SUSE
  + Dropped:
    argus-3.0.6.1.tar.bz2
    README.SuSE
  + Fixes in Specfile
    Changed permissions to 0644 for argus.service to clear rpmlint warning
    Removed System/Magic from chmod command, to clear rpmlint warning
    Removed %%attr stanza from %%doc lines, unneeded, and they were set incorrectly
    in the first place, and causing rpmlint to fail, due to unreadable files
    Removed %%config from argus.service in %%files, not neccessary, and causes rpmlint
    warning
* Wed Feb 20 2013 cfarrell@suse.com
- license update: GPL-2.0 and LGPL-2.1 and BSD-3-Clause and MIT
  Based on audit of 3.0.6.1
* Sun Oct 28 2012 p.drouand@gmail.com
- Remove argus-3.0.0-flex.diff from Coolo : argus_get_leng string
  is no longer used since 3.0.6 release
* Sun Oct 28 2012 p.drouand@gmail.com
- - Update to 3.0.6.1 version :
  Bugs fixed :
  * Correct memory leak and deadlock issues for argus and radium;
  * Argus and radium get some protection from port scanners;
  * The client release also fixes a number of bugs with geolocation data,
    especially country code aggregation and printing. We also fixed
    meta-data label merging, multicast identification, and some minor
    issues with variable namespace collisions.
- Remove sysvinit support and improve systemd support
* Fri Oct 26 2012 coolo@suse.com
- remove prototypes for flex, they conflict with the real ones
* Sun Nov 27 2011 coolo@suse.com
- do not package argus twice
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sun Mar  7 2010 ro@suse.de
- drop autoreconf for now
* Fri Sep 12 2008 anosek@suse.cz
- updated to version 3.0.0
  - Use SASL for security
  - 64-bit Architecture Support
  - New Record Format
  - More protocols like IPv6, MPLS, VLANS
- dropped obsoleted patch (uninitialized.patch)
- disabled patch fixes-1.patch
* Sun Jun  1 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Fri Mar 30 2007 ssommer@suse.de
- add flex and bison to BuildRequires
* Fri Nov 10 2006 ro@suse.de
- fix manpage permissions
* Tue Apr  4 2006 mmarek@suse.cz
- use RPM_OPT_FLAGS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 mmarek@suse.cz
- fixed uninitialized variable warning
  [#137379] (uninitialized.patch)
* Thu Aug 19 2004 postadal@suse.cz
- updated to version 2.0.6 (fixes 1)
- splitted in two new (sub)packages (argus-server, argus-client)
* Thu Mar 18 2004 postadal@suse.cz
- fixed permissions of man pages and documentation [#36325]
* Thu Feb 12 2004 ro@suse.de
- adapt to change in libpcap: include moved to pcap_bpf.h
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Aug 25 2003 postadal@suse.cz
- modified init script
- added sysconfig metadata [#28836]
- use new stop_on_removal/restart_on_upate macros
* Mon Jun  2 2003 ro@suse.de
- fixed rcargus symlink
* Fri Jan  3 2003 postadal@suse.cz
- added metadata in sysconfig template
* Wed Aug 21 2002 ro@suse.de
- fix build on ppc64
* Fri Aug 16 2002 postadal@suse.cz
- added %%insserv_prereq and %%fillup_prereq to PreReq [#17787]
* Tue Aug  6 2002 adrian@suse.de
- remove tcpdump man page again
  (fixes file conflict with tcpdump package)
* Tue Jul 30 2002 postadal@suse.cz
- udate to version 2.0.5
  * multithreaded, configuration files, syslog support, secure access
  * record changes
  * a lot of new features for server and client
* Wed Jul 24 2002 kukuk@suse.de
- Replase rc.config with sysconfig/argus in README.SuSE
* Wed Jul 24 2002 kukuk@suse.de
- Don't parse rc.config
* Mon Feb 25 2002 postadal@suse.cz
- modified copyright in /etc/init.d/argus
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Mon Jan 14 2002 cihlar@suse.cz
- use %%{_libdir}
* Thu Dec 13 2001 ro@suse.de
- moved rc.config.d -> sysconfig
* Tue Dec 11 2001 cihlar@suse.cz
- source /etc/rc.config.d/argus.rc.config in init script
- fixed to remove variables which are in
  /etc/rc.config.d/argus.rc.config now from /etc/rc.config
* Mon Dec 10 2001 cihlar@suse.cz
- removed START_ARGUS
* Fri Nov 23 2001 cihlar@suse.cz
- Fixed Url
* Mon Aug 13 2001 cihlar@suse.cz
- really removed whole files from patches
- fixed README.SuSE
* Thu Jul 26 2001 cihlar@suse.cz
- removed tcpdump man page
* Tue Jul 24 2001 cihlar@suse.cz
- fixed to compile on ia64
- fixed includes
- added BuildRoot
- use suse_update_config
- removed whole files from patches
- added Url
- bzipped sources
* Mon Jul  2 2001 choeger@suse.de
- bugfix: init script was not LSB compliant, Bugzilla ID#8969
- update to version 1.8.1
* Fri Dec  1 2000 ro@suse.de
- use normal tcpd (wrapper-lib)
- fixed startscript
* Wed Mar  1 2000 choeger@suse.de
- added mandir
* Tue Feb 15 2000 aj@suse.de
- fix headers for sparc
* Thu Sep 16 1999 uli@suse.de
- fixed headers for PPC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Jul 11 1999 ro@suse.de
- libpcap is an extra package now
* Thu Apr 22 1999 ro@suse.de
- fixed for alpha (ip_hl like other little-endian)
* Wed Dec  9 1998 choeger@suse.de
- completed new init-script
* Mon Nov 23 1998 choeger@suse.de
- new version and new init-script
* Tue Oct  6 1998 ro@suse.de
- dont redeclare sys_errlist or strcpy for glibc
- dont cast to a char* where you're not supposed to
* Mon May  4 1998 choeger@suse.de
- new package 1.7.beta.1b
